Change Log
==========

All notable changes will appear in this log. Changes are categorized into
"Added", "Changed", "Fixed", and "Removed". To see a comparison between
releases on Github, click or follow the release version number URL.

For information on the style of this change log, see
`keepachangelog.com <http://keepachangelog.com/>`__.



v0.0.1.post1
============

* Fix packaging issue (missing package data)


v0.0.1.post0
============

* Fix packaging issue


v0.0.1
======

* First public release
